@@ -1,4 +1,4 @@
-from edi_835_parser.elements import Element
+from edi_835_parser.elements import Element, Code
 
 # https://x12.org/codes/claim-adjustment-group-codes
 adjustment_group_codes = {
@@ -12,5 +12,6 @@ adjustment_group_codes = {
 
 class AdjustmentGroupCode(Element):
 
-	def parser(self, value: str) -> str:
-		return adjustment_group_codes.get(value, value)
+	def parser(self, value: str) -> Code:
+		description = adjustment_group_codes.get(value, None)
+		return Code(value, description)
