@@ -5,7 +5,9 @@ date_qualifiers = {
 	'050': 'received',
 	'150': 'service period start',
 	'151': 'service period end',
-	'472': 'service'
+	'472': 'service',
+	'232': 'claim statement period start',
+	'233': 'claim statement period end',
 }
 
 
