@@ -19,8 +19,8 @@ def find_identifier(segment) -> str:
 	segment = split_segment(segment)
 	return segment[0]
 
-def get_element(segment: List[str], index: int) -> Optional[str]:
-	element = None
+def get_element(segment: List[str], index: int, default=None) -> Optional[str]:
+	element = default
 	if index < len(segment):
 		element = segment[index]
 
